@@ -1598,6 +1598,16 @@ compile:
 			continue;
 		}
 
+		if(!stricmp(token, ".use"))
+		{
+			while(NULL != (token = getToken()))
+			{
+				if(!Script::use(token))
+					slog(Slog::levelWarning) << token << ": package missing" << endl;
+			}
+			continue;
+		}
+
 		if(!stricmp(token, ".sub"))
 		{
 			name = getToken();
@@ -1714,6 +1724,10 @@ compile:
 			continue;
 		}
 
+		if(token[0] == '.')
+			if(preProcess(token, script))
+				continue;
+
 		ignore = false;
 		if(*token == '@')
 		{
@@ -1741,9 +1755,9 @@ compile:
 		argc = 0;
 		while(argc < 32 && NULL != (token = getToken()))
 		{
-			if(*token == '$')
+			if(token[0] == '$' && isalpha(token[1]))
 			{
-				token = (char *)cmds->getLast(++token);
+				token = (char *)getDefined(++token);
 				if(!token)
 					token = "";
 			}
