@@ -67,6 +67,7 @@ class CCXX_CLASS_EXPORT ScriptInterp;
 #define	KEYWORD_INDEX_SIZE 37
 #define SYMBOL_INDEX_SIZE 187
 #define SCRIPT_INDEX_SIZE KEYWORD_INDEX_SIZE
+#define	SCRIPT_PREPROCESSOR_OVERRIDE 1
 
 class Script
 {
@@ -910,6 +911,25 @@ protected:
 	 */
 	void commit(void);
 
+	/**
+	 * used to create dialect specific pre-precessor directives.
+	 *
+	 * @return true if directive claimed.
+	 * @param directive
+	 * @param script object being built
+	 */
+	virtual bool preProcess(const char *directive, Name *script)
+		{return false;};
+
+	/**
+	 * Used to process '$const' inserts.
+	 *
+	 * @return string if found.
+	 * @param script token being substituted.
+	 */
+	virtual const char *getDefined(const char *token)
+		{return cmds->getLast(token);};
+
 public:
 	/**
 	 * Fetch named script.
